pitchtools.ordered_chromatic_pitch_class_numbers_are_within_ordered_chromatic_pitch_numbers
===========================================================================================

.. autofunction:: abjad.tools.pitchtools.ordered_chromatic_pitch_class_numbers_are_within_ordered_chromatic_pitch_numbers.ordered_chromatic_pitch_class_numbers_are_within_ordered_chromatic_pitch_numbers
